==> vtk-8.1.0-3-aarch64.pkg.tar.xz: vtk/vtkResampleWithDataSet.java <==
// java wrapper for vtkResampleWithDataSet object
//

package vtk;
import vtk.*;

public class vtkResampleWithDataSet extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_2(id0); }

  private native void SetSourceConnection_3(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_3(id0); }

  private native void SetCategoricalData_4(boolean id0);
  public void SetCategoricalData(boolean id0)
    { SetCategoricalData_4(id0); }

  private native boolean GetCategoricalData_5();
  public boolean GetCategoricalData()
    { return GetCategoricalData_5(); }

  private native void SetPassCellArrays_6(boolean id0);
  public void SetPassCellArrays(boolean id0)
    { SetPassCellArrays_6(id0); }

  private native boolean GetPassCellArrays_7();
  public boolean GetPassCellArrays()
    { return GetPassCellArrays_7(); }

  private native void PassCellArraysOn_8();
  public void PassCellArraysOn()
    { PassCellArraysOn_8(); }

  private native void PassCellArraysOff_9();
  public void PassCellArraysOff()
    { PassCellArraysOff_9(); }

  private native void SetPassPointArrays_10(boolean id0);
  public void SetPassPointArrays(boolean id0)
    { SetPassPointArrays_10(id0); }

  private native boolean GetPassPointArrays_11();
  public boolean GetPassPointArrays()
    { return GetPassPointArrays_11(); }

  private native void PassPointArraysOn_12();
  public void PassPointArraysOn()
    { PassPointArraysOn_12(); }

  private native void PassPointArraysOff_13();
  public void PassPointArraysOff()
    { PassPointArraysOff_13(); }

  private native void SetPassFieldArrays_14(boolean id0);
  public void SetPassFieldArrays(boolean id0)
    { SetPassFieldArrays_14(id0); }

  private native boolean GetPassFieldArrays_15();
  public boolean GetPassFieldArrays()
    { return GetPassFieldArrays_15(); }

  private native void PassFieldArraysOn_16();
  public void PassFieldArraysOn()
    { PassFieldArraysOn_16(); }

  private native void PassFieldArraysOff_17();
  public void PassFieldArraysOff()
    { PassFieldArraysOff_17(); }

  private native void SetTolerance_18(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_18(id0); }

  private native double GetTolerance_19();
  public double GetTolerance()
    { return GetTolerance_19(); }

  private native void SetComputeTolerance_20(boolean id0);
  public void SetComputeTolerance(boolean id0)
    { SetComputeTolerance_20(id0); }

  private native boolean GetComputeTolerance_21();
  public boolean GetComputeTolerance()
    { return GetComputeTolerance_21(); }

  private native void ComputeToleranceOn_22();
  public void ComputeToleranceOn()
    { ComputeToleranceOn_22(); }

  private native void ComputeToleranceOff_23();
  public void ComputeToleranceOff()
    { ComputeToleranceOff_23(); }

  private native void SetMarkBlankPointsAndCells_24(boolean id0);
  public void SetMarkBlankPointsAndCells(boolean id0)
    { SetMarkBlankPointsAndCells_24(id0); }

  private native boolean GetMarkBlankPointsAndCells_25();
  public boolean GetMarkBlankPointsAndCells()
    { return GetMarkBlankPointsAndCells_25(); }

  private native void MarkBlankPointsAndCellsOn_26();
  public void MarkBlankPointsAndCellsOn()
    { MarkBlankPointsAndCellsOn_26(); }

  private native void MarkBlankPointsAndCellsOff_27();
  public void MarkBlankPointsAndCellsOff()
    { MarkBlankPointsAndCellsOff_27(); }

  private native int GetMTime_28();
  public int GetMTime()
    { return GetMTime_28(); }

  public vtkResampleWithDataSet() { super(); }

  public vtkResampleWithDataSet(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkResampleWithDataSet.java <==
// java wrapper for vtkResampleWithDataSet object
//

package vtk;
import vtk.*;

public class vtkResampleWithDataSet extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_2(id0); }

  private native void SetSourceConnection_3(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_3(id0); }

  private native void SetCategoricalData_4(boolean id0);
  public void SetCategoricalData(boolean id0)
    { SetCategoricalData_4(id0); }

  private native boolean GetCategoricalData_5();
  public boolean GetCategoricalData()
    { return GetCategoricalData_5(); }

  private native void SetPassCellArrays_6(boolean id0);
  public void SetPassCellArrays(boolean id0)
    { SetPassCellArrays_6(id0); }

  private native boolean GetPassCellArrays_7();
  public boolean GetPassCellArrays()
    { return GetPassCellArrays_7(); }

  private native void PassCellArraysOn_8();
  public void PassCellArraysOn()
    { PassCellArraysOn_8(); }

  private native void PassCellArraysOff_9();
  public void PassCellArraysOff()
    { PassCellArraysOff_9(); }

  private native void SetPassPointArrays_10(boolean id0);
  public void SetPassPointArrays(boolean id0)
    { SetPassPointArrays_10(id0); }

  private native boolean GetPassPointArrays_11();
  public boolean GetPassPointArrays()
    { return GetPassPointArrays_11(); }

  private native void PassPointArraysOn_12();
  public void PassPointArraysOn()
    { PassPointArraysOn_12(); }

  private native void PassPointArraysOff_13();
  public void PassPointArraysOff()
    { PassPointArraysOff_13(); }

  private native void SetPassFieldArrays_14(boolean id0);
  public void SetPassFieldArrays(boolean id0)
    { SetPassFieldArrays_14(id0); }

  private native boolean GetPassFieldArrays_15();
  public boolean GetPassFieldArrays()
    { return GetPassFieldArrays_15(); }

  private native void PassFieldArraysOn_16();
  public void PassFieldArraysOn()
    { PassFieldArraysOn_16(); }

  private native void PassFieldArraysOff_17();
  public void PassFieldArraysOff()
    { PassFieldArraysOff_17(); }

  private native void SetTolerance_18(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_18(id0); }

  private native double GetTolerance_19();
  public double GetTolerance()
    { return GetTolerance_19(); }

  private native void SetComputeTolerance_20(boolean id0);
  public void SetComputeTolerance(boolean id0)
    { SetComputeTolerance_20(id0); }

  private native boolean GetComputeTolerance_21();
  public boolean GetComputeTolerance()
    { return GetComputeTolerance_21(); }

  private native void ComputeToleranceOn_22();
  public void ComputeToleranceOn()
    { ComputeToleranceOn_22(); }

  private native void ComputeToleranceOff_23();
  public void ComputeToleranceOff()
    { ComputeToleranceOff_23(); }

  private native void SetMarkBlankPointsAndCells_24(boolean id0);
  public void SetMarkBlankPointsAndCells(boolean id0)
    { SetMarkBlankPointsAndCells_24(id0); }

  private native boolean GetMarkBlankPointsAndCells_25();
  public boolean GetMarkBlankPointsAndCells()
    { return GetMarkBlankPointsAndCells_25(); }

  private native void MarkBlankPointsAndCellsOn_26();
  public void MarkBlankPointsAndCellsOn()
    { MarkBlankPointsAndCellsOn_26(); }

  private native void MarkBlankPointsAndCellsOff_27();
  public void MarkBlankPointsAndCellsOff()
    { MarkBlankPointsAndCellsOff_27(); }

  private native void SetCellLocatorPrototype_28(vtkAbstractCellLocator id0);
  public void SetCellLocatorPrototype(vtkAbstractCellLocator id0)
    { SetCellLocatorPrototype_28(id0); }

  private native long GetCellLocatorPrototype_29();
  public vtkAbstractCellLocator GetCellLocatorPrototype() {
    long temp = GetCellLocatorPrototype_29();

    if (temp == 0) return null;
    return (vtkAbstractCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_30();
  public int GetMTime()
    { return GetMTime_30(); }

  public vtkResampleWithDataSet() { super(); }

  public vtkResampleWithDataSet(long id) { super(id); }
  public native long   VTKInit();

}
